/****************************************************************************
** Meta object code from reading C++ file 'oxygenframeshadow.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../oxygen-6.6.5/kstyle/oxygenframeshadow.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'oxygenframeshadow.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN6Oxygen18FrameShadowFactoryE_t {};
} // unnamed namespace

template <> constexpr inline auto Oxygen::FrameShadowFactory::qt_create_metaobjectdata<qt_meta_tag_ZN6Oxygen18FrameShadowFactoryE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Oxygen::FrameShadowFactory",
        "widgetDestroyed",
        ""
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'widgetDestroyed'
        QtMocHelpers::SlotData<void(QObject *)>(1, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QObjectStar, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FrameShadowFactory, qt_meta_tag_ZN6Oxygen18FrameShadowFactoryE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Oxygen::FrameShadowFactory::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Oxygen18FrameShadowFactoryE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Oxygen18FrameShadowFactoryE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Oxygen18FrameShadowFactoryE_t>.metaTypes,
    nullptr
} };

void Oxygen::FrameShadowFactory::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FrameShadowFactory *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->widgetDestroyed((*reinterpret_cast<std::add_pointer_t<QObject*>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *Oxygen::FrameShadowFactory::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Oxygen::FrameShadowFactory::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Oxygen18FrameShadowFactoryE_t>.strings))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Oxygen::FrameShadowFactory::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 1)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 1;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 1)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 1;
    }
    return _id;
}
namespace {
struct qt_meta_tag_ZN6Oxygen15FrameShadowBaseE_t {};
} // unnamed namespace

template <> constexpr inline auto Oxygen::FrameShadowBase::qt_create_metaobjectdata<qt_meta_tag_ZN6Oxygen15FrameShadowBaseE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Oxygen::FrameShadowBase"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FrameShadowBase, qt_meta_tag_ZN6Oxygen15FrameShadowBaseE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Oxygen::FrameShadowBase::staticMetaObject = { {
    QMetaObject::SuperData::link<QWidget::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Oxygen15FrameShadowBaseE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Oxygen15FrameShadowBaseE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Oxygen15FrameShadowBaseE_t>.metaTypes,
    nullptr
} };

void Oxygen::FrameShadowBase::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FrameShadowBase *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Oxygen::FrameShadowBase::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Oxygen::FrameShadowBase::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Oxygen15FrameShadowBaseE_t>.strings))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int Oxygen::FrameShadowBase::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN6Oxygen17SunkenFrameShadowE_t {};
} // unnamed namespace

template <> constexpr inline auto Oxygen::SunkenFrameShadow::qt_create_metaobjectdata<qt_meta_tag_ZN6Oxygen17SunkenFrameShadowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Oxygen::SunkenFrameShadow"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<SunkenFrameShadow, qt_meta_tag_ZN6Oxygen17SunkenFrameShadowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Oxygen::SunkenFrameShadow::staticMetaObject = { {
    QMetaObject::SuperData::link<FrameShadowBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Oxygen17SunkenFrameShadowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Oxygen17SunkenFrameShadowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Oxygen17SunkenFrameShadowE_t>.metaTypes,
    nullptr
} };

void Oxygen::SunkenFrameShadow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<SunkenFrameShadow *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Oxygen::SunkenFrameShadow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Oxygen::SunkenFrameShadow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Oxygen17SunkenFrameShadowE_t>.strings))
        return static_cast<void*>(this);
    return FrameShadowBase::qt_metacast(_clname);
}

int Oxygen::SunkenFrameShadow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = FrameShadowBase::qt_metacall(_c, _id, _a);
    return _id;
}
namespace {
struct qt_meta_tag_ZN6Oxygen15FlatFrameShadowE_t {};
} // unnamed namespace

template <> constexpr inline auto Oxygen::FlatFrameShadow::qt_create_metaobjectdata<qt_meta_tag_ZN6Oxygen15FlatFrameShadowE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "Oxygen::FlatFrameShadow"
    };

    QtMocHelpers::UintData qt_methods {
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<FlatFrameShadow, qt_meta_tag_ZN6Oxygen15FlatFrameShadowE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject Oxygen::FlatFrameShadow::staticMetaObject = { {
    QMetaObject::SuperData::link<FrameShadowBase::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Oxygen15FlatFrameShadowE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Oxygen15FlatFrameShadowE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN6Oxygen15FlatFrameShadowE_t>.metaTypes,
    nullptr
} };

void Oxygen::FlatFrameShadow::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<FlatFrameShadow *>(_o);
    (void)_t;
    (void)_c;
    (void)_id;
    (void)_a;
}

const QMetaObject *Oxygen::FlatFrameShadow::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Oxygen::FlatFrameShadow::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN6Oxygen15FlatFrameShadowE_t>.strings))
        return static_cast<void*>(this);
    return FrameShadowBase::qt_metacast(_clname);
}

int Oxygen::FlatFrameShadow::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = FrameShadowBase::qt_metacall(_c, _id, _a);
    return _id;
}
QT_WARNING_POP
