/****************************************************************************
** Meta object code from reading C++ file 'oxygensliderdemowidget.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.18)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../../oxygen-6.6.5/kstyle/demo/oxygensliderdemowidget.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'oxygensliderdemowidget.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.18. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_Oxygen__ProgressBar_t {
    QByteArrayData data[5];
    char stringdata0[63];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Oxygen__ProgressBar_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Oxygen__ProgressBar_t qt_meta_stringdata_Oxygen__ProgressBar = {
    {
QT_MOC_LITERAL(0, 0, 19), // "Oxygen::ProgressBar"
QT_MOC_LITERAL(1, 20, 24), // "toggleInvertedAppearance"
QT_MOC_LITERAL(2, 45, 0), // ""
QT_MOC_LITERAL(3, 46, 5), // "value"
QT_MOC_LITERAL(4, 52, 10) // "toggleBusy"

    },
    "Oxygen::ProgressBar\0toggleInvertedAppearance\0"
    "\0value\0toggleBusy"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Oxygen__ProgressBar[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       2,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    1,   24,    2, 0x0a /* Public */,
       4,    1,   27,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, QMetaType::Bool,    2,

       0        // eod
};

void Oxygen::ProgressBar::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<ProgressBar *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->toggleInvertedAppearance((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->toggleBusy((*reinterpret_cast< bool(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Oxygen::ProgressBar::staticMetaObject = { {
    QMetaObject::SuperData::link<QObject::staticMetaObject>(),
    qt_meta_stringdata_Oxygen__ProgressBar.data,
    qt_meta_data_Oxygen__ProgressBar,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Oxygen::ProgressBar::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Oxygen::ProgressBar::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Oxygen__ProgressBar.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int Oxygen::ProgressBar::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 2)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 2)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 2;
    }
    return _id;
}
struct qt_meta_stringdata_Oxygen__SliderDemoWidget_t {
    QByteArrayData data[5];
    char stringdata0[69];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_Oxygen__SliderDemoWidget_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_Oxygen__SliderDemoWidget_t qt_meta_stringdata_Oxygen__SliderDemoWidget = {
    {
QT_MOC_LITERAL(0, 0, 24), // "Oxygen::SliderDemoWidget"
QT_MOC_LITERAL(1, 25, 9), // "benchmark"
QT_MOC_LITERAL(2, 35, 0), // ""
QT_MOC_LITERAL(3, 36, 13), // "updateSliders"
QT_MOC_LITERAL(4, 50, 18) // "updateTickPosition"

    },
    "Oxygen::SliderDemoWidget\0benchmark\0\0"
    "updateSliders\0updateTickPosition"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_Oxygen__SliderDemoWidget[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    0,   29,    2, 0x0a /* Public */,
       3,    1,   30,    2, 0x08 /* Private */,
       4,    1,   33,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,

       0        // eod
};

void Oxygen::SliderDemoWidget::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<SliderDemoWidget *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->benchmark(); break;
        case 1: _t->updateSliders((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 2: _t->updateTickPosition((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject Oxygen::SliderDemoWidget::staticMetaObject = { {
    QMetaObject::SuperData::link<DemoWidget::staticMetaObject>(),
    qt_meta_stringdata_Oxygen__SliderDemoWidget.data,
    qt_meta_data_Oxygen__SliderDemoWidget,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *Oxygen::SliderDemoWidget::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *Oxygen::SliderDemoWidget::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_Oxygen__SliderDemoWidget.stringdata0))
        return static_cast<void*>(this);
    return DemoWidget::qt_metacast(_clname);
}

int Oxygen::SliderDemoWidget::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = DemoWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
